@@ -48,6 +48,7 @@ SERVICE_RENAMES = {
     'iot1click-projects': 'iot-1click-projects',
     'iotevents-data': 'iot-events-data',
     'iotevents': 'iot-events',
+    'iotwireless': 'iot-wireless',
     'kinesisanalytics': 'kinesis-analytics',
     'kinesisanalyticsv2': 'kinesis-analytics-v2',
     'kinesisvideo': 'kinesis-video',
@@ -87,7 +88,9 @@ ENDPOINT_PREFIX_OVERRIDE = {
     # iotevents data endpoints.json and service-2.json don't line up.
     'ioteventsdata': 'data.iotevents',
     'iotsecuredtunneling': 'api.tunneling.iot',
+    'iotwireless': 'api.iotwireless',
 }
+
 NOT_SUPPORTED_IN_SDK = [
     'mobileanalytics',
     'transcribestreaming',
